Module: Aws::AgentRegistryControl
- Defined in:
- lib/aws-sdk-agentregistrycontrol/endpoint_parameters.rb,
sig/client.rbs,
sig/errors.rbs,
sig/params.rbs,
sig/waiters.rbs,
sig/resource.rbs,
lib/aws-sdk-agentregistrycontrol/plugins/endpoints.rb,
lib/aws-sdk-agentregistrycontrol/endpoint_provider.rb,
lib/aws-sdk-agentregistrycontrol/client_api.rb,
lib/aws-sdk-agentregistrycontrol/endpoints.rb,
lib/aws-sdk-agentregistrycontrol/resource.rb,
lib/aws-sdk-agentregistrycontrol/waiters.rb,
lib/aws-sdk-agentregistrycontrol/errors.rb,
lib/aws-sdk-agentregistrycontrol/client.rb,
lib/aws-sdk-agentregistrycontrol/types.rb,
lib/aws-sdk-agentregistrycontrol.rb
Overview
This module provides support for Agent Registry Control. This module is available in the
aws-sdk-agentregistrycontrol gem.
Client
The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.
agent_registry_control = Aws::AgentRegistryControl::Client.new
resp = agent_registry_control.create_registry(params)
See Client for more information.
Errors
Errors returned from Agent Registry Control are defined in the Errors module and all extend Errors::ServiceError.
begin
# do stuff
rescue Aws::AgentRegistryControl::Errors::ServiceError
# rescues all Agent Registry Control API errors
end
See Errors for more information.
Defined Under Namespace
Modules: ClientApi, Endpoints, Errors, Params, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource
service collapse
- GEM_VERSION =
'1.0.0'