Class: Aws::AgentRegistryControl::Types::A2aAgentCardDescriptor

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

Descriptor that defines the content of an A2A (Agent-to-Agent) agent card registry record. The content is validated against the A2A protocol schema.

Constant Summary collapse

SENSITIVE =
[:data]

Instance Attribute Summary collapse

Instance Attribute Details

#dataString

The A2A agent card content, serialized as descriptor payload data.

Returns:

  • (String)


32
33
34
35
36
37
38
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 32

class A2aAgentCardDescriptor < Struct.new(
  :data,
  :data_schema_version,
  :source)
  SENSITIVE = [:data]
  include Aws::Structure
end

#data_schema_versionString

The schema version of the descriptor payload.

Returns:

  • (String)


32
33
34
35
36
37
38
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 32

class A2aAgentCardDescriptor < Struct.new(
  :data,
  :data_schema_version,
  :source)
  SENSITIVE = [:data]
  include Aws::Structure
end

#sourceTypes::DescriptorSource

The optional source configuration used to synchronize the A2A agent card descriptor content.



32
33
34
35
36
37
38
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 32

class A2aAgentCardDescriptor < Struct.new(
  :data,
  :data_schema_version,
  :source)
  SENSITIVE = [:data]
  include Aws::Structure
end