Class: Aws::AgentRegistryControl::Types::AgUiDescriptor
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::AgUiDescriptor
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
A registry record descriptor for the AG-UI (Agent-User Interaction) protocol.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source ⇒ Types::DescriptorSource
The source configuration that defines where descriptor content is retrieved from.
Instance Attribute Details
#source ⇒ Types::DescriptorSource
The source configuration that defines where descriptor content is retrieved from.
63 64 65 66 67 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 63 class AgUiDescriptor < Struct.new( :source) SENSITIVE = [] include Aws::Structure end |