Class: Aws::AgentRegistryControl::Types::AgentSkillsAdditionalData
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::AgentSkillsAdditionalData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
Additional data associated with an agent skills definition descriptor.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#skill_md ⇒ Types::AgentSkillsMdDescriptor
The markdown skill content associated with an agent skills definition.
Instance Attribute Details
#skill_md ⇒ Types::AgentSkillsMdDescriptor
The markdown skill content associated with an agent skills definition.
150 151 152 153 154 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 150 class AgentSkillsAdditionalData < Struct.new( :skill_md) SENSITIVE = [] include Aws::Structure end |