Class: Aws::AgentRegistryControl::Types::AgentSkillsMdDescriptor
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::AgentSkillsMdDescriptor
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
Markdown-format descriptor containing an agent skills document.
Constant Summary collapse
- SENSITIVE =
[:data]
Instance Attribute Summary collapse
-
#data ⇒ String
The agent skills markdown content, serialized as descriptor payload data.
-
#data_schema_version ⇒ String
The schema version of the descriptor payload.
-
#source ⇒ Types::DescriptorSource
The optional source configuration used to synchronize the agent skills markdown content.
Instance Attribute Details
#data ⇒ String
The agent skills markdown content, serialized as descriptor payload data.
113 114 115 116 117 118 119 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 113 class AgentSkillsMdDescriptor < Struct.new( :data, :data_schema_version, :source) SENSITIVE = [:data] include Aws::Structure end |
#data_schema_version ⇒ String
The schema version of the descriptor payload.
113 114 115 116 117 118 119 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 113 class AgentSkillsMdDescriptor < Struct.new( :data, :data_schema_version, :source) SENSITIVE = [:data] include Aws::Structure end |
#source ⇒ Types::DescriptorSource
The optional source configuration used to synchronize the agent skills markdown content.
113 114 115 116 117 118 119 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 113 class AgentSkillsMdDescriptor < Struct.new( :data, :data_schema_version, :source) SENSITIVE = [:data] include Aws::Structure end |