Class: Aws::AgentRegistryControl::Types::ApprovalConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

Configuration for the registry's record approval workflow. Controls whether records submitted for approval require manual review before they become approved and discoverable, or are auto-approved. When no auto-approval rules are configured, submitted records require manual review.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_approval_rulesArray<String>

The rules that determine which registry records are automatically approved on submission. When omitted or empty, submitted records require manual review.

Returns:

  • (Array<String>)


135
136
137
138
139
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 135

class ApprovalConfiguration < Struct.new(
  :auto_approval_rules)
  SENSITIVE = []
  include Aws::Structure
end