Class: Aws::AgentRegistryControl::Types::AuthorizingClaimMatchValueType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

The value and match operator used to authorize a claim during JWT validation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#claim_match_operatorString

The operator used to compare the claim value against the expected value.

Returns:

  • (String)


179
180
181
182
183
184
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 179

class AuthorizingClaimMatchValueType < Struct.new(
  :claim_match_value,
  :claim_match_operator)
  SENSITIVE = []
  include Aws::Structure
end

#claim_match_valueTypes::ClaimMatchValueType

The expected value or values that the claim is compared against.



179
180
181
182
183
184
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 179

class AuthorizingClaimMatchValueType < Struct.new(
  :claim_match_value,
  :claim_match_operator)
  SENSITIVE = []
  include Aws::Structure
end