Class: Aws::AgentRegistryControl::Types::AutoDetection

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

The auto-detection properties for a registry, including the requested configuration and the current detection status. When auto-detection is enabled and the scope preconditions are met, the registry is automatically populated with discovered resources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationTypes::AutoDetectionConfiguration

The auto-detection settings that control how resources are discovered for the registry.



298
299
300
301
302
303
304
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 298

class AutoDetection < Struct.new(
  :configuration,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current auto-detection status. ACTIVE indicates that the registry is actively being populated with detected resources. INACTIVE indicates that the preconditions required at the configured scope are not currently met.

Returns:

  • (String)


298
299
300
301
302
303
304
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 298

class AutoDetection < Struct.new(
  :configuration,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

A human-readable explanation of the current auto-detection status. Typically populated when the status requires additional context.

Returns:

  • (String)


298
299
300
301
302
303
304
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 298

class AutoDetection < Struct.new(
  :configuration,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end