Class: Aws::AgentRegistryControl::Types::AutoDetectionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

The customer-defined auto-detection settings for a registry.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabledBoolean

Specifies whether auto-detection is requested for the registry. Setting this to true is necessary but not sufficient for auto-detection to become active; the preconditions of the configured scope must also be met.

Returns:

  • (Boolean)


323
324
325
326
327
328
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 323

class AutoDetectionConfiguration < Struct.new(
  :scope,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

The source from which resources are detected. For example, ORGANIZATION sources resources from all member accounts of an Amazon Web Services organization.

Returns:

  • (String)


323
324
325
326
327
328
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 323

class AutoDetectionConfiguration < Struct.new(
  :scope,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end