Class: Aws::AgentRegistryControl::Types::ClaimMatchValueType

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

Note:

ClaimMatchValueType is a union - when making an API calls you must set exactly one of the members.

Note:

ClaimMatchValueType is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ClaimMatchValueType corresponding to the set member.

The expected value used to match a claim. Exactly one member is set.

Defined Under Namespace

Classes: MatchValueString, MatchValueStringList, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#match_value_stringString

A single string value to match the claim against.

Returns:

  • (String)


202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 202

class ClaimMatchValueType < Struct.new(
  :match_value_string,
  :match_value_string_list,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class MatchValueString < ClaimMatchValueType; end
  class MatchValueStringList < ClaimMatchValueType; end
  class Unknown < ClaimMatchValueType; end
end

#match_value_string_listArray<String>

A list of string values to match the claim against.

Returns:

  • (Array<String>)


202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 202

class ClaimMatchValueType < Struct.new(
  :match_value_string,
  :match_value_string_list,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class MatchValueString < ClaimMatchValueType; end
  class MatchValueStringList < ClaimMatchValueType; end
  class Unknown < ClaimMatchValueType; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



202
203
204
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 202

def unknown
  @unknown
end