Class: Aws::AgentRegistryControl::Types::CreateRegistryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

Request structure for creating a registry

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#approval_configurationTypes::ApprovalConfiguration

Approval configuration for registry records



507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507

class CreateRegistryRequest < Struct.new(
  :name,
  :description,
  :encryption_configuration,
  :discovery_configuration,
  :client_token,
  :tags,
  :approval_configuration,
  :auto_detection_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#auto_detection_configurationTypes::AutoDetectionConfiguration

The optional auto-detection configuration for the registry. When provided, the registry is automatically populated with resources discovered according to the configuration. Omit this field for registries whose records are managed exclusively through the Agent Registry Control API.



507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507

class CreateRegistryRequest < Struct.new(
  :name,
  :description,
  :encryption_configuration,
  :discovery_configuration,
  :client_token,
  :tags,
  :approval_configuration,
  :auto_detection_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service ignores the request, but does not return an error.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507

class CreateRegistryRequest < Struct.new(
  :name,
  :description,
  :encryption_configuration,
  :discovery_configuration,
  :client_token,
  :tags,
  :approval_configuration,
  :auto_detection_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

The description of the registry

Returns:

  • (String)


507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507

class CreateRegistryRequest < Struct.new(
  :name,
  :description,
  :encryption_configuration,
  :discovery_configuration,
  :client_token,
  :tags,
  :approval_configuration,
  :auto_detection_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#discovery_configurationTypes::DiscoveryConfiguration

Discovery configuration for the registry



507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507

class CreateRegistryRequest < Struct.new(
  :name,
  :description,
  :encryption_configuration,
  :discovery_configuration,
  :client_token,
  :tags,
  :approval_configuration,
  :auto_detection_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#encryption_configurationTypes::EncryptionConfiguration

The optional server-side encryption configuration for the registry. When you provide this field, the specified customer-managed Amazon Web Services KMS key encrypts the registry's content. Omit this field to use an Amazon Web Services-owned encryption key. You cannot change the encryption configuration after registry creation.



507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507

class CreateRegistryRequest < Struct.new(
  :name,
  :description,
  :encryption_configuration,
  :discovery_configuration,
  :client_token,
  :tags,
  :approval_configuration,
  :auto_detection_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#nameString

The name of the registry

Returns:

  • (String)


507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507

class CreateRegistryRequest < Struct.new(
  :name,
  :description,
  :encryption_configuration,
  :discovery_configuration,
  :client_token,
  :tags,
  :approval_configuration,
  :auto_detection_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tagsHash<String,String>

Tags to associate with the registry

Returns:

  • (Hash<String,String>)


507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507

class CreateRegistryRequest < Struct.new(
  :name,
  :description,
  :encryption_configuration,
  :discovery_configuration,
  :client_token,
  :tags,
  :approval_configuration,
  :auto_detection_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end