Class: Aws::AgentRegistryControl::Types::DiscoveryConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

Discovery configuration for the registry. Controls how consumers are authorized to search the registry and invoke its MCP endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authorizer_configurationTypes::AuthorizerConfiguration

The authorizer configuration for the registry. Required when authorizerType is CUSTOM_JWT.



587
588
589
590
591
592
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 587

class DiscoveryConfiguration < Struct.new(
  :authorizer_configuration,
  :authorizer_type)
  SENSITIVE = []
  include Aws::Structure
end

#authorizer_typeString

The type of authorizer that controls how consumers access the registry's search and MCP invoke operations.

Returns:

  • (String)


587
588
589
590
591
592
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 587

class DiscoveryConfiguration < Struct.new(
  :authorizer_configuration,
  :authorizer_type)
  SENSITIVE = []
  include Aws::Structure
end