Class: Aws::AgentRegistryControl::Types::GetRegistryResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

Response structure for getting a registry

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#approval_configurationTypes::ApprovalConfiguration

Approval configuration for registry records



987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987

class GetRegistryResponse < Struct.new(
  :name,
  :description,
  :registry_id,
  :registry_arn,
  :discovery_configuration,
  :encryption_configuration,
  :approval_configuration,
  :status,
  :status_reason,
  :auto_detection,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#auto_detectionTypes::AutoDetection

The registry's auto-detection properties, including the requested configuration and the current detection status. Present only when auto-detection was configured for the registry.



987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987

class GetRegistryResponse < Struct.new(
  :name,
  :description,
  :registry_id,
  :registry_arn,
  :discovery_configuration,
  :encryption_configuration,
  :approval_configuration,
  :status,
  :status_reason,
  :auto_detection,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#created_atTime

The timestamp when the registry was created

Returns:

  • (Time)


987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987

class GetRegistryResponse < Struct.new(
  :name,
  :description,
  :registry_id,
  :registry_arn,
  :discovery_configuration,
  :encryption_configuration,
  :approval_configuration,
  :status,
  :status_reason,
  :auto_detection,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

The description of the registry

Returns:

  • (String)


987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987

class GetRegistryResponse < Struct.new(
  :name,
  :description,
  :registry_id,
  :registry_arn,
  :discovery_configuration,
  :encryption_configuration,
  :approval_configuration,
  :status,
  :status_reason,
  :auto_detection,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#discovery_configurationTypes::DiscoveryConfiguration

Discovery configuration for the registry



987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987

class GetRegistryResponse < Struct.new(
  :name,
  :description,
  :registry_id,
  :registry_arn,
  :discovery_configuration,
  :encryption_configuration,
  :approval_configuration,
  :status,
  :status_reason,
  :auto_detection,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#encryption_configurationTypes::EncryptionConfiguration

The server-side encryption configuration for the registry. Appears only when a customer-managed Amazon Web Services KMS key encrypts the registry.



987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987

class GetRegistryResponse < Struct.new(
  :name,
  :description,
  :registry_id,
  :registry_arn,
  :discovery_configuration,
  :encryption_configuration,
  :approval_configuration,
  :status,
  :status_reason,
  :auto_detection,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#nameString

The name of the registry

Returns:

  • (String)


987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987

class GetRegistryResponse < Struct.new(
  :name,
  :description,
  :registry_id,
  :registry_arn,
  :discovery_configuration,
  :encryption_configuration,
  :approval_configuration,
  :status,
  :status_reason,
  :auto_detection,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#registry_arnString

The ARN of the registry

Returns:

  • (String)


987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987

class GetRegistryResponse < Struct.new(
  :name,
  :description,
  :registry_id,
  :registry_arn,
  :discovery_configuration,
  :encryption_configuration,
  :approval_configuration,
  :status,
  :status_reason,
  :auto_detection,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#registry_idString

The unique identifier of the registry

Returns:

  • (String)


987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987

class GetRegistryResponse < Struct.new(
  :name,
  :description,
  :registry_id,
  :registry_arn,
  :discovery_configuration,
  :encryption_configuration,
  :approval_configuration,
  :status,
  :status_reason,
  :auto_detection,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#statusString

Current status of the registry

Returns:

  • (String)


987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987

class GetRegistryResponse < Struct.new(
  :name,
  :description,
  :registry_id,
  :registry_arn,
  :discovery_configuration,
  :encryption_configuration,
  :approval_configuration,
  :status,
  :status_reason,
  :auto_detection,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#status_reasonString

The reason for the current status. Typically populated when the status indicates a failure state.

Returns:

  • (String)


987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987

class GetRegistryResponse < Struct.new(
  :name,
  :description,
  :registry_id,
  :registry_arn,
  :discovery_configuration,
  :encryption_configuration,
  :approval_configuration,
  :status,
  :status_reason,
  :auto_detection,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end

#updated_atTime

The timestamp when the registry was last updated

Returns:

  • (Time)


987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987

class GetRegistryResponse < Struct.new(
  :name,
  :description,
  :registry_id,
  :registry_arn,
  :discovery_configuration,
  :encryption_configuration,
  :approval_configuration,
  :status,
  :status_reason,
  :auto_detection,
  :created_at,
  :updated_at)
  SENSITIVE = [:description]
  include Aws::Structure
end