Class: Aws::AgentRegistryControl::Types::ManagedVpcResource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

A service-managed private endpoint provisioned within a customer VPC.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#endpoint_ip_address_typeString

The IP address type used by the private endpoint, either IPV4 or IPV6.

Returns:

  • (String)


923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 923

class ManagedVpcResource < Struct.new(
  :vpc_identifier,
  :subnet_ids,
  :endpoint_ip_address_type,
  :security_group_ids,
  :tags,
  :routing_domain)
  SENSITIVE = []
  include Aws::Structure
end

#routing_domainString

The routing domain used to resolve traffic through the private endpoint.

Returns:

  • (String)


923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 923

class ManagedVpcResource < Struct.new(
  :vpc_identifier,
  :subnet_ids,
  :endpoint_ip_address_type,
  :security_group_ids,
  :tags,
  :routing_domain)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The identifiers of the security groups associated with the private endpoint network interfaces.

Returns:

  • (Array<String>)


923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 923

class ManagedVpcResource < Struct.new(
  :vpc_identifier,
  :subnet_ids,
  :endpoint_ip_address_type,
  :security_group_ids,
  :tags,
  :routing_domain)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The identifiers of the subnets in which the private endpoint network interfaces are placed.

Returns:

  • (Array<String>)


923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 923

class ManagedVpcResource < Struct.new(
  :vpc_identifier,
  :subnet_ids,
  :endpoint_ip_address_type,
  :security_group_ids,
  :tags,
  :routing_domain)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A map of tag keys to tag values.

Returns:

  • (Hash<String,String>)


923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 923

class ManagedVpcResource < Struct.new(
  :vpc_identifier,
  :subnet_ids,
  :endpoint_ip_address_type,
  :security_group_ids,
  :tags,
  :routing_domain)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_identifierString

The identifier of the VPC in which the private endpoint is provisioned.

Returns:

  • (String)


923
924
925
926
927
928
929
930
931
932
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 923

class ManagedVpcResource < Struct.new(
  :vpc_identifier,
  :subnet_ids,
  :endpoint_ip_address_type,
  :security_group_ids,
  :tags,
  :routing_domain)
  SENSITIVE = []
  include Aws::Structure
end