Class: Aws::AgentRegistryControl::Types::McpServerAdditionalData
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::McpServerAdditionalData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
Additional data for an MCP server descriptor
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tools ⇒ Types::McpToolsDescriptor
The MCP tools descriptor that defines the tools exposed by the MCP server.
Instance Attribute Details
#tools ⇒ Types::McpToolsDescriptor
The MCP tools descriptor that defines the tools exposed by the MCP server.
1203 1204 1205 1206 1207 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1203 class McpServerAdditionalData < Struct.new( :tools) SENSITIVE = [] include Aws::Structure end |