Class: Aws::AgentRegistryControl::Types::McpServerDescriptor

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

Descriptor that defines the content of an MCP (Model Context Protocol) server registry record, including the server definition and its tool definitions. The content is validated against the MCP protocol schema.

Constant Summary collapse

SENSITIVE =
[:data]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_dataTypes::McpServerAdditionalData

Additional data associated with the MCP server descriptor, such as tool definitions.



1234
1235
1236
1237
1238
1239
1240
1241
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1234

class McpServerDescriptor < Struct.new(
  :data,
  :data_schema_version,
  :additional_data,
  :source)
  SENSITIVE = [:data]
  include Aws::Structure
end

#dataString

The MCP server descriptor content, serialized as descriptor payload data.

Returns:

  • (String)


1234
1235
1236
1237
1238
1239
1240
1241
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1234

class McpServerDescriptor < Struct.new(
  :data,
  :data_schema_version,
  :additional_data,
  :source)
  SENSITIVE = [:data]
  include Aws::Structure
end

#data_schema_versionString

The schema version of the descriptor payload.

Returns:

  • (String)


1234
1235
1236
1237
1238
1239
1240
1241
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1234

class McpServerDescriptor < Struct.new(
  :data,
  :data_schema_version,
  :additional_data,
  :source)
  SENSITIVE = [:data]
  include Aws::Structure
end

#sourceTypes::DescriptorSource

The optional source configuration used to synchronize the MCP server descriptor content.



1234
1235
1236
1237
1238
1239
1240
1241
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1234

class McpServerDescriptor < Struct.new(
  :data,
  :data_schema_version,
  :additional_data,
  :source)
  SENSITIVE = [:data]
  include Aws::Structure
end