Class: Aws::AgentRegistryControl::Types::McpToolsDescriptor
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::McpToolsDescriptor
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
MCP tools descriptor containing tool definitions
Constant Summary collapse
- SENSITIVE =
[:data]
Instance Attribute Summary collapse
-
#data ⇒ String
The MCP tools descriptor content, serialized as descriptor payload data.
-
#data_schema_version ⇒ String
The schema version of the descriptor payload.
Instance Attribute Details
#data ⇒ String
The MCP tools descriptor content, serialized as descriptor payload data.
1256 1257 1258 1259 1260 1261 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1256 class McpToolsDescriptor < Struct.new( :data, :data_schema_version) SENSITIVE = [:data] include Aws::Structure end |
#data_schema_version ⇒ String
The schema version of the descriptor payload.
1256 1257 1258 1259 1260 1261 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1256 class McpToolsDescriptor < Struct.new( :data, :data_schema_version) SENSITIVE = [:data] include Aws::Structure end |