Class: Aws::AgentRegistryControl::Types::PrivateEndpointOverride

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

A mapping of a domain to the private endpoint used to reach it.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domainString

The domain name to which this private endpoint override applies.

Returns:

  • (String)


1306
1307
1308
1309
1310
1311
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1306

class PrivateEndpointOverride < Struct.new(
  :domain,
  :private_endpoint)
  SENSITIVE = []
  include Aws::Structure
end

#private_endpointTypes::PrivateEndpoint

The private endpoint used to reach the specified domain.



1306
1307
1308
1309
1310
1311
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1306

class PrivateEndpointOverride < Struct.new(
  :domain,
  :private_endpoint)
  SENSITIVE = []
  include Aws::Structure
end