Class: Aws::AgentRegistryControl::Types::Provenance

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

One provenance entry describing the lineage of a registry record.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#relationString

The relationship between the registry record and its provenance source.

Returns:

  • (String)


1338
1339
1340
1341
1342
1343
1344
1345
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1338

class Provenance < Struct.new(
  :relation,
  :source_id,
  :source_type,
  :source_details)
  SENSITIVE = []
  include Aws::Structure
end

#source_detailsTypes::SourceDetails

Additional details about the upstream source that the registry record was detected from, such as the AgentCore Gateway or Runtime configuration. The populated member corresponds to the source type.



1338
1339
1340
1341
1342
1343
1344
1345
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1338

class Provenance < Struct.new(
  :relation,
  :source_id,
  :source_type,
  :source_details)
  SENSITIVE = []
  include Aws::Structure
end

#source_idString

The identifier of the upstream source that the registry record was detected from.

Returns:

  • (String)


1338
1339
1340
1341
1342
1343
1344
1345
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1338

class Provenance < Struct.new(
  :relation,
  :source_id,
  :source_type,
  :source_details)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

The type of the upstream source that the registry record was detected from.

Returns:

  • (String)


1338
1339
1340
1341
1342
1343
1344
1345
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1338

class Provenance < Struct.new(
  :relation,
  :source_id,
  :source_type,
  :source_details)
  SENSITIVE = []
  include Aws::Structure
end