Class: Aws::AgentRegistryControl::Types::SelfManagedLatticeResource

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

Note:

SelfManagedLatticeResource is a union - when making an API calls you must set exactly one of the members.

Note:

SelfManagedLatticeResource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SelfManagedLatticeResource corresponding to the set member.

A self-managed private endpoint backed by a VPC Lattice resource configuration. Exactly one member is set.

Defined Under Namespace

Classes: ResourceConfigurationIdentifier, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_configuration_identifierString

The identifier of the VPC Lattice resource configuration, specified as a resource configuration ID or ARN.

Returns:

  • (String)


1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1347

class SelfManagedLatticeResource < Struct.new(
  :resource_configuration_identifier,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ResourceConfigurationIdentifier < SelfManagedLatticeResource; end
  class Unknown < SelfManagedLatticeResource; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1347
1348
1349
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1347

def unknown
  @unknown
end