Class: Aws::AgentRegistryControl::Types::UpdatedAgentSkillsAdditionalDataFields
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::UpdatedAgentSkillsAdditionalDataFields
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
The set of agent skills additional-data fields that can be individually updated.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#skill_md ⇒ Types::UpdatedAgentSkillsMdDescriptor
The patch for the agent skills markdown descriptor field.
Instance Attribute Details
#skill_md ⇒ Types::UpdatedAgentSkillsMdDescriptor
The patch for the agent skills markdown descriptor field.
1849 1850 1851 1852 1853 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1849 class UpdatedAgentSkillsAdditionalDataFields < Struct.new( :skill_md) SENSITIVE = [] include Aws::Structure end |