Class: Aws::AgentRegistryControl::Types::UpdatedDiscoveryConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

The discovery configuration fields to update on a registry. Omit this structure to leave the discovery configuration unchanged.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authorizer_configurationTypes::UpdatedAuthorizerConfiguration

Authorization configuration for the registry, with PATCH semantics



2631
2632
2633
2634
2635
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 2631

class UpdatedDiscoveryConfiguration < Struct.new(
  :authorizer_configuration)
  SENSITIVE = []
  include Aws::Structure
end