Class: Aws::AgentRegistryControl::Types::WorkloadIdentityDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::WorkloadIdentityDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
Workload identity details associated with a source resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#workload_identity_arn ⇒ String
The Amazon Resource Name (ARN) of the workload identity associated with the source resource.
Instance Attribute Details
#workload_identity_arn ⇒ String
The Amazon Resource Name (ARN) of the workload identity associated with the source resource.
2852 2853 2854 2855 2856 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 2852 class WorkloadIdentityDetails < Struct.new( :workload_identity_arn) SENSITIVE = [] include Aws::Structure end |