Class: Aws::AgentRegistryControl::Waiters::RegistryReady
- Inherits:
-
Object
- Object
- Aws::AgentRegistryControl::Waiters::RegistryReady
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-agentregistrycontrol/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ RegistryReady
constructor
A new instance of RegistryReady.
-
#wait(params = {}) ⇒ Types::GetRegistryResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ RegistryReady
Returns a new instance of RegistryReady.
85 86 |
# File 'lib/aws-sdk-agentregistrycontrol/waiters.rb', line 85
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
129 130 131 |
# File 'lib/aws-sdk-agentregistrycontrol/waiters.rb', line 129 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetRegistryResponse
Returns a response object which responds to the following methods:
- #name => String
- #description => String
- #registry_id => String
- #registry_arn => String
- #discovery_configuration => Types::DiscoveryConfiguration
- #approval_configuration => Types::ApprovalConfiguration
- #status => String
- #status_reason => String
- #created_at => Time
- #updated_at => Time
124 |
# File 'lib/aws-sdk-agentregistrycontrol/waiters.rb', line 124
def wait: (
|