Class: Aws::AgentRegistryControl::Waiters::RegistryRecordApproved

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-agentregistrycontrol/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ RegistryRecordApproved

Returns a new instance of RegistryRecordApproved.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 5
  • :delay (Integer) — default: 30
  • :before_attempt (Proc)
  • :before_wait (Proc)


141
142
# File 'lib/aws-sdk-agentregistrycontrol/waiters.rb', line 141

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



185
186
187
# File 'lib/aws-sdk-agentregistrycontrol/waiters.rb', line 185

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetRegistryRecordResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :registry_id (required, String)

    The identifier of the registry containing the record (ARN or ID)

  • :record_id (required, String)

    The identifier of the registry record to retrieve (ARN or ID)

Returns:



180
# File 'lib/aws-sdk-agentregistrycontrol/waiters.rb', line 180

def wait: (