Class: Aws::AgentRegistryControl::Types::A2aAgentCardDescriptor
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::A2aAgentCardDescriptor
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
Descriptor that defines the content of an A2A (Agent-to-Agent) agent card registry record. The content is validated against the A2A protocol schema.
Constant Summary collapse
- SENSITIVE =
[:data]
Instance Attribute Summary collapse
-
#data ⇒ String
The A2A agent card content, serialized as descriptor payload data.
-
#data_schema_version ⇒ String
The schema version of the descriptor payload.
-
#source ⇒ Types::DescriptorSource
The optional source configuration used to synchronize the A2A agent card descriptor content.
Instance Attribute Details
#data ⇒ String
The A2A agent card content, serialized as descriptor payload data.
32 33 34 35 36 37 38 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 32 class A2aAgentCardDescriptor < Struct.new( :data, :data_schema_version, :source) SENSITIVE = [:data] include Aws::Structure end |
#data_schema_version ⇒ String
The schema version of the descriptor payload.
32 33 34 35 36 37 38 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 32 class A2aAgentCardDescriptor < Struct.new( :data, :data_schema_version, :source) SENSITIVE = [:data] include Aws::Structure end |
#source ⇒ Types::DescriptorSource
The optional source configuration used to synchronize the A2A agent card descriptor content.
32 33 34 35 36 37 38 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 32 class A2aAgentCardDescriptor < Struct.new( :data, :data_schema_version, :source) SENSITIVE = [:data] include Aws::Structure end |