Class: Aws::AgentRegistryControl::Types::AgentSkillsAdditionalData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

Additional data associated with an agent skills definition descriptor.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#skill_mdTypes::AgentSkillsMdDescriptor

The markdown skill content associated with an agent skills definition.



62
63
64
65
66
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 62

class AgentSkillsAdditionalData < Struct.new(
  :skill_md)
  SENSITIVE = []
  include Aws::Structure
end