Class: Aws::AgentRegistryControl::Types::AgentSkillsAdditionalData
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::AgentSkillsAdditionalData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
Additional data associated with an agent skills definition descriptor.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#skill_md ⇒ Types::AgentSkillsMdDescriptor
The markdown skill content associated with an agent skills definition.
Instance Attribute Details
#skill_md ⇒ Types::AgentSkillsMdDescriptor
The markdown skill content associated with an agent skills definition.
62 63 64 65 66 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 62 class AgentSkillsAdditionalData < Struct.new( :skill_md) SENSITIVE = [] include Aws::Structure end |