Class: Aws::AgentRegistryControl::Types::AuthorizerConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::AuthorizerConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
Note:
AuthorizerConfiguration is a union - when making an API calls you must set exactly one of the members.
Note:
AuthorizerConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of AuthorizerConfiguration corresponding to the set member.
The authorizer configuration for a registry. Exactly one member is set.
Defined Under Namespace
Classes: CustomJwtAuthorizer, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_jwt_authorizer ⇒ Types::CustomJWTAuthorizerConfiguration
Configuration for a custom JWT authorizer.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#custom_jwt_authorizer ⇒ Types::CustomJWTAuthorizerConfiguration
Configuration for a custom JWT authorizer.
154 155 156 157 158 159 160 161 162 163 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 154 class AuthorizerConfiguration < Struct.new( :custom_jwt_authorizer, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CustomJwtAuthorizer < AuthorizerConfiguration; end class Unknown < AuthorizerConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
154 155 156 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 154 def unknown @unknown end |