Class: Aws::AgentRegistryControl::Types::AuthorizingClaimMatchValueType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::AuthorizingClaimMatchValueType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
The value and match operator used to authorize a claim during JWT validation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#claim_match_operator ⇒ String
The operator used to compare the claim value against the expected value.
-
#claim_match_value ⇒ Types::ClaimMatchValueType
The expected value or values that the claim is compared against.
Instance Attribute Details
#claim_match_operator ⇒ String
The operator used to compare the claim value against the expected value.
179 180 181 182 183 184 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 179 class AuthorizingClaimMatchValueType < Struct.new( :claim_match_value, :claim_match_operator) SENSITIVE = [] include Aws::Structure end |
#claim_match_value ⇒ Types::ClaimMatchValueType
The expected value or values that the claim is compared against.
179 180 181 182 183 184 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 179 class AuthorizingClaimMatchValueType < Struct.new( :claim_match_value, :claim_match_operator) SENSITIVE = [] include Aws::Structure end |