Class: Aws::AgentRegistryControl::Types::ClaimMatchValueType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::ClaimMatchValueType
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
Note:
ClaimMatchValueType is a union - when making an API calls you must set exactly one of the members.
Note:
ClaimMatchValueType is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ClaimMatchValueType corresponding to the set member.
The expected value used to match a claim. Exactly one member is set.
Defined Under Namespace
Classes: MatchValueString, MatchValueStringList, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#match_value_string ⇒ String
A single string value to match the claim against.
-
#match_value_string_list ⇒ Array<String>
A list of string values to match the claim against.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#match_value_string ⇒ String
A single string value to match the claim against.
202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 202 class ClaimMatchValueType < Struct.new( :match_value_string, :match_value_string_list, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class MatchValueString < ClaimMatchValueType; end class MatchValueStringList < ClaimMatchValueType; end class Unknown < ClaimMatchValueType; end end |
#match_value_string_list ⇒ Array<String>
A list of string values to match the claim against.
202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 202 class ClaimMatchValueType < Struct.new( :match_value_string, :match_value_string_list, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class MatchValueString < ClaimMatchValueType; end class MatchValueStringList < ClaimMatchValueType; end class Unknown < ClaimMatchValueType; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
202 203 204 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 202 def unknown @unknown end |