Class: Aws::AgentRegistryControl::Types::CreateRegistryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::CreateRegistryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
Request structure for creating a registry
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#approval_configuration ⇒ Types::ApprovalConfiguration
Approval configuration for registry records.
-
#auto_detection_configuration ⇒ Types::AutoDetectionConfiguration
The optional auto-detection configuration for the registry.
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time.
-
#description ⇒ String
The description of the registry.
-
#discovery_configuration ⇒ Types::DiscoveryConfiguration
Discovery configuration for the registry.
-
#encryption_configuration ⇒ Types::EncryptionConfiguration
The optional server-side encryption configuration for the registry.
-
#name ⇒ String
The name of the registry.
-
#tags ⇒ Hash<String,String>
Tags to associate with the registry.
Instance Attribute Details
#approval_configuration ⇒ Types::ApprovalConfiguration
Approval configuration for registry records
507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507 class CreateRegistryRequest < Struct.new( :name, :description, :encryption_configuration, :discovery_configuration, :client_token, :tags, :approval_configuration, :auto_detection_configuration) SENSITIVE = [:description] include Aws::Structure end |
#auto_detection_configuration ⇒ Types::AutoDetectionConfiguration
The optional auto-detection configuration for the registry. When provided, the registry is automatically populated with resources discovered according to the configuration. Omit this field for registries whose records are managed exclusively through the Agent Registry Control API.
507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507 class CreateRegistryRequest < Struct.new( :name, :description, :encryption_configuration, :discovery_configuration, :client_token, :tags, :approval_configuration, :auto_detection_configuration) SENSITIVE = [:description] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service ignores the request, but does not return an error.
A suitable default value is auto-generated. You should normally not need to pass this option.
507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507 class CreateRegistryRequest < Struct.new( :name, :description, :encryption_configuration, :discovery_configuration, :client_token, :tags, :approval_configuration, :auto_detection_configuration) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the registry
507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507 class CreateRegistryRequest < Struct.new( :name, :description, :encryption_configuration, :discovery_configuration, :client_token, :tags, :approval_configuration, :auto_detection_configuration) SENSITIVE = [:description] include Aws::Structure end |
#discovery_configuration ⇒ Types::DiscoveryConfiguration
Discovery configuration for the registry
507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507 class CreateRegistryRequest < Struct.new( :name, :description, :encryption_configuration, :discovery_configuration, :client_token, :tags, :approval_configuration, :auto_detection_configuration) SENSITIVE = [:description] include Aws::Structure end |
#encryption_configuration ⇒ Types::EncryptionConfiguration
The optional server-side encryption configuration for the registry. When you provide this field, the specified customer-managed Amazon Web Services KMS key encrypts the registry's content. Omit this field to use an Amazon Web Services-owned encryption key. You cannot change the encryption configuration after registry creation.
507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507 class CreateRegistryRequest < Struct.new( :name, :description, :encryption_configuration, :discovery_configuration, :client_token, :tags, :approval_configuration, :auto_detection_configuration) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the registry
507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507 class CreateRegistryRequest < Struct.new( :name, :description, :encryption_configuration, :discovery_configuration, :client_token, :tags, :approval_configuration, :auto_detection_configuration) SENSITIVE = [:description] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags to associate with the registry
507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 507 class CreateRegistryRequest < Struct.new( :name, :description, :encryption_configuration, :discovery_configuration, :client_token, :tags, :approval_configuration, :auto_detection_configuration) SENSITIVE = [:description] include Aws::Structure end |