Class: Aws::AgentRegistryControl::Types::CustomClaimValidationType
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::CustomClaimValidationType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
A validation rule applied to a single claim of an inbound JWT.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorizing_claim_match_value ⇒ Types::AuthorizingClaimMatchValueType
The value and match operator used to authorize the claim.
-
#inbound_token_claim_name ⇒ String
The name of the claim in the inbound token to validate.
-
#inbound_token_claim_value_type ⇒ String
The value type of the claim in the inbound token, either a string or an array of strings.
Instance Attribute Details
#authorizing_claim_match_value ⇒ Types::AuthorizingClaimMatchValueType
The value and match operator used to authorize the claim.
378 379 380 381 382 383 384 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 378 class CustomClaimValidationType < Struct.new( :inbound_token_claim_name, :inbound_token_claim_value_type, :authorizing_claim_match_value) SENSITIVE = [] include Aws::Structure end |
#inbound_token_claim_name ⇒ String
The name of the claim in the inbound token to validate.
378 379 380 381 382 383 384 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 378 class CustomClaimValidationType < Struct.new( :inbound_token_claim_name, :inbound_token_claim_value_type, :authorizing_claim_match_value) SENSITIVE = [] include Aws::Structure end |
#inbound_token_claim_value_type ⇒ String
The value type of the claim in the inbound token, either a string or an array of strings.
378 379 380 381 382 383 384 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 378 class CustomClaimValidationType < Struct.new( :inbound_token_claim_name, :inbound_token_claim_value_type, :authorizing_claim_match_value) SENSITIVE = [] include Aws::Structure end |