Class: Aws::AgentRegistryControl::Types::DescriptorSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::DescriptorSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
The source configuration that defines where descriptor content is retrieved from.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#from_url ⇒ Types::DescriptorSourceFromUrl
URL-based descriptor source, populated when descriptor content is synchronized from a URL.
Instance Attribute Details
#from_url ⇒ Types::DescriptorSourceFromUrl
URL-based descriptor source, populated when descriptor content is synchronized from a URL.
513 514 515 516 517 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 513 class DescriptorSource < Struct.new( :from_url) SENSITIVE = [] include Aws::Structure end |