Class: Aws::AgentRegistryControl::Types::DescriptorSourceFromUrl
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::DescriptorSourceFromUrl
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
URL-based descriptor source configuration, with credential provider configurations for authenticated URL retrieval.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#credential_provider_configurations ⇒ Array<Types::RegistryRecordCredentialProviderConfiguration>
The credential providers used to authenticate when fetching descriptor content from the source URL.
-
#url ⇒ String
The URL from which the descriptor content is retrieved.
Instance Attribute Details
#credential_provider_configurations ⇒ Array<Types::RegistryRecordCredentialProviderConfiguration>
The credential providers used to authenticate when fetching descriptor content from the source URL.
533 534 535 536 537 538 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 533 class DescriptorSourceFromUrl < Struct.new( :url, :credential_provider_configurations) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The URL from which the descriptor content is retrieved.
533 534 535 536 537 538 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 533 class DescriptorSourceFromUrl < Struct.new( :url, :credential_provider_configurations) SENSITIVE = [] include Aws::Structure end |