Class: Aws::AgentRegistryControl::Types::Descriptors

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

The typed set of descriptors for a registry record. Exactly one descriptor field is populated based on the record type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#a2a_agent_cardTypes::A2aAgentCardDescriptor

The A2A agent card descriptor, populated when the record type is AGENT.



563
564
565
566
567
568
569
570
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 563

class Descriptors < Struct.new(
  :mcp_server,
  :a2a_agent_card,
  :agent_skills_definition,
  :custom)
  SENSITIVE = []
  include Aws::Structure
end

#agent_skills_definitionTypes::AgentSkillsDefinitionDescriptor

The agent skills definition descriptor, populated when the record type is SKILL.



563
564
565
566
567
568
569
570
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 563

class Descriptors < Struct.new(
  :mcp_server,
  :a2a_agent_card,
  :agent_skills_definition,
  :custom)
  SENSITIVE = []
  include Aws::Structure
end

#customTypes::CustomDescriptor

The custom descriptor, populated when the record type is CUSTOM.



563
564
565
566
567
568
569
570
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 563

class Descriptors < Struct.new(
  :mcp_server,
  :a2a_agent_card,
  :agent_skills_definition,
  :custom)
  SENSITIVE = []
  include Aws::Structure
end

#mcp_serverTypes::McpServerDescriptor

The MCP server descriptor, populated when the record type is MCP.



563
564
565
566
567
568
569
570
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 563

class Descriptors < Struct.new(
  :mcp_server,
  :a2a_agent_card,
  :agent_skills_definition,
  :custom)
  SENSITIVE = []
  include Aws::Structure
end