Class: Aws::AgentRegistryControl::Types::DiscoveryConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::DiscoveryConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
Discovery configuration for the registry. Controls how consumers are authorized to search the registry and invoke its MCP endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorizer_configuration ⇒ Types::AuthorizerConfiguration
The authorizer configuration for the registry.
-
#authorizer_type ⇒ String
The type of authorizer that controls how consumers access the registry's search and MCP invoke operations.
Instance Attribute Details
#authorizer_configuration ⇒ Types::AuthorizerConfiguration
The authorizer configuration for the registry. Required when authorizerType is CUSTOM_JWT.
587 588 589 590 591 592 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 587 class DiscoveryConfiguration < Struct.new( :authorizer_configuration, :authorizer_type) SENSITIVE = [] include Aws::Structure end |
#authorizer_type ⇒ String
The type of authorizer that controls how consumers access the registry's search and MCP invoke operations.
587 588 589 590 591 592 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 587 class DiscoveryConfiguration < Struct.new( :authorizer_configuration, :authorizer_type) SENSITIVE = [] include Aws::Structure end |