Class: Aws::AgentRegistryControl::Types::EncryptionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::EncryptionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
The server-side encryption configuration for a registry. Specifies a customer-managed Amazon Web Services KMS key used to encrypt the registry's content.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the customer-managed Amazon Web Services KMS key used to encrypt the registry's content.
Instance Attribute Details
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the customer-managed Amazon Web Services KMS key used to encrypt the registry's content. The key must be a symmetric encryption key in the same Amazon Web Services account and Region as the registry.
793 794 795 796 797 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 793 class EncryptionConfiguration < Struct.new( :kms_key_arn) SENSITIVE = [] include Aws::Structure end |