Class: Aws::AgentRegistryControl::Types::GetRegistryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::GetRegistryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
Response structure for getting a registry
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#approval_configuration ⇒ Types::ApprovalConfiguration
Approval configuration for registry records.
-
#auto_detection ⇒ Types::AutoDetection
The registry's auto-detection properties, including the requested configuration and the current detection status.
-
#created_at ⇒ Time
The timestamp when the registry was created.
-
#description ⇒ String
The description of the registry.
-
#discovery_configuration ⇒ Types::DiscoveryConfiguration
Discovery configuration for the registry.
-
#encryption_configuration ⇒ Types::EncryptionConfiguration
The server-side encryption configuration for the registry.
-
#name ⇒ String
The name of the registry.
-
#registry_arn ⇒ String
The ARN of the registry.
-
#registry_id ⇒ String
The unique identifier of the registry.
-
#status ⇒ String
Current status of the registry.
-
#status_reason ⇒ String
The reason for the current status.
-
#updated_at ⇒ Time
The timestamp when the registry was last updated.
Instance Attribute Details
#approval_configuration ⇒ Types::ApprovalConfiguration
Approval configuration for registry records
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987 class GetRegistryResponse < Struct.new( :name, :description, :registry_id, :registry_arn, :discovery_configuration, :encryption_configuration, :approval_configuration, :status, :status_reason, :auto_detection, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#auto_detection ⇒ Types::AutoDetection
The registry's auto-detection properties, including the requested configuration and the current detection status. Present only when auto-detection was configured for the registry.
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987 class GetRegistryResponse < Struct.new( :name, :description, :registry_id, :registry_arn, :discovery_configuration, :encryption_configuration, :approval_configuration, :status, :status_reason, :auto_detection, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the registry was created
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987 class GetRegistryResponse < Struct.new( :name, :description, :registry_id, :registry_arn, :discovery_configuration, :encryption_configuration, :approval_configuration, :status, :status_reason, :auto_detection, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the registry
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987 class GetRegistryResponse < Struct.new( :name, :description, :registry_id, :registry_arn, :discovery_configuration, :encryption_configuration, :approval_configuration, :status, :status_reason, :auto_detection, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#discovery_configuration ⇒ Types::DiscoveryConfiguration
Discovery configuration for the registry
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987 class GetRegistryResponse < Struct.new( :name, :description, :registry_id, :registry_arn, :discovery_configuration, :encryption_configuration, :approval_configuration, :status, :status_reason, :auto_detection, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#encryption_configuration ⇒ Types::EncryptionConfiguration
The server-side encryption configuration for the registry. Appears only when a customer-managed Amazon Web Services KMS key encrypts the registry.
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987 class GetRegistryResponse < Struct.new( :name, :description, :registry_id, :registry_arn, :discovery_configuration, :encryption_configuration, :approval_configuration, :status, :status_reason, :auto_detection, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the registry
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987 class GetRegistryResponse < Struct.new( :name, :description, :registry_id, :registry_arn, :discovery_configuration, :encryption_configuration, :approval_configuration, :status, :status_reason, :auto_detection, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#registry_arn ⇒ String
The ARN of the registry
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987 class GetRegistryResponse < Struct.new( :name, :description, :registry_id, :registry_arn, :discovery_configuration, :encryption_configuration, :approval_configuration, :status, :status_reason, :auto_detection, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#registry_id ⇒ String
The unique identifier of the registry
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987 class GetRegistryResponse < Struct.new( :name, :description, :registry_id, :registry_arn, :discovery_configuration, :encryption_configuration, :approval_configuration, :status, :status_reason, :auto_detection, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#status ⇒ String
Current status of the registry
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987 class GetRegistryResponse < Struct.new( :name, :description, :registry_id, :registry_arn, :discovery_configuration, :encryption_configuration, :approval_configuration, :status, :status_reason, :auto_detection, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#status_reason ⇒ String
The reason for the current status. Typically populated when the status indicates a failure state.
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987 class GetRegistryResponse < Struct.new( :name, :description, :registry_id, :registry_arn, :discovery_configuration, :encryption_configuration, :approval_configuration, :status, :status_reason, :auto_detection, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the registry was last updated
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 987 class GetRegistryResponse < Struct.new( :name, :description, :registry_id, :registry_arn, :discovery_configuration, :encryption_configuration, :approval_configuration, :status, :status_reason, :auto_detection, :created_at, :updated_at) SENSITIVE = [:description] include Aws::Structure end |