Class: Aws::AgentRegistryControl::Types::HttpDescriptor
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::HttpDescriptor
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
A registry record descriptor for the HTTP protocol. This descriptor is source-only: its content is synchronized from the configured source URL rather than supplied inline.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source ⇒ Types::DescriptorSource
The source configuration that defines where descriptor content is retrieved from.
Instance Attribute Details
#source ⇒ Types::DescriptorSource
The source configuration that defines where descriptor content is retrieved from.
1015 1016 1017 1018 1019 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1015 class HttpDescriptor < Struct.new( :source) SENSITIVE = [] include Aws::Structure end |