Class: Aws::AgentRegistryControl::Types::ManagedVpcResource
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::ManagedVpcResource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
A service-managed private endpoint provisioned within a customer VPC.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#endpoint_ip_address_type ⇒ String
The IP address type used by the private endpoint, either IPV4 or IPV6.
-
#routing_domain ⇒ String
The routing domain used to resolve traffic through the private endpoint.
-
#security_group_ids ⇒ Array<String>
The identifiers of the security groups associated with the private endpoint network interfaces.
-
#subnet_ids ⇒ Array<String>
The identifiers of the subnets in which the private endpoint network interfaces are placed.
-
#tags ⇒ Hash<String,String>
A map of tag keys to tag values.
-
#vpc_identifier ⇒ String
The identifier of the VPC in which the private endpoint is provisioned.
Instance Attribute Details
#endpoint_ip_address_type ⇒ String
The IP address type used by the private endpoint, either IPV4 or IPV6.
923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 923 class ManagedVpcResource < Struct.new( :vpc_identifier, :subnet_ids, :endpoint_ip_address_type, :security_group_ids, :tags, :routing_domain) SENSITIVE = [] include Aws::Structure end |
#routing_domain ⇒ String
The routing domain used to resolve traffic through the private endpoint.
923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 923 class ManagedVpcResource < Struct.new( :vpc_identifier, :subnet_ids, :endpoint_ip_address_type, :security_group_ids, :tags, :routing_domain) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The identifiers of the security groups associated with the private endpoint network interfaces.
923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 923 class ManagedVpcResource < Struct.new( :vpc_identifier, :subnet_ids, :endpoint_ip_address_type, :security_group_ids, :tags, :routing_domain) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The identifiers of the subnets in which the private endpoint network interfaces are placed.
923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 923 class ManagedVpcResource < Struct.new( :vpc_identifier, :subnet_ids, :endpoint_ip_address_type, :security_group_ids, :tags, :routing_domain) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A map of tag keys to tag values.
923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 923 class ManagedVpcResource < Struct.new( :vpc_identifier, :subnet_ids, :endpoint_ip_address_type, :security_group_ids, :tags, :routing_domain) SENSITIVE = [] include Aws::Structure end |
#vpc_identifier ⇒ String
The identifier of the VPC in which the private endpoint is provisioned.
923 924 925 926 927 928 929 930 931 932 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 923 class ManagedVpcResource < Struct.new( :vpc_identifier, :subnet_ids, :endpoint_ip_address_type, :security_group_ids, :tags, :routing_domain) SENSITIVE = [] include Aws::Structure end |