Class: Aws::AgentRegistryControl::Types::McpServerDescriptor
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::McpServerDescriptor
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
Descriptor that defines the content of an MCP (Model Context Protocol) server registry record, including the server definition and its tool definitions. The content is validated against the MCP protocol schema.
Constant Summary collapse
- SENSITIVE =
[:data]
Instance Attribute Summary collapse
-
#additional_data ⇒ Types::McpServerAdditionalData
Additional data associated with the MCP server descriptor, such as tool definitions.
-
#data ⇒ String
The MCP server descriptor content, serialized as descriptor payload data.
-
#data_schema_version ⇒ String
The schema version of the descriptor payload.
-
#source ⇒ Types::DescriptorSource
The optional source configuration used to synchronize the MCP server descriptor content.
Instance Attribute Details
#additional_data ⇒ Types::McpServerAdditionalData
Additional data associated with the MCP server descriptor, such as tool definitions.
1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1234 class McpServerDescriptor < Struct.new( :data, :data_schema_version, :additional_data, :source) SENSITIVE = [:data] include Aws::Structure end |
#data ⇒ String
The MCP server descriptor content, serialized as descriptor payload data.
1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1234 class McpServerDescriptor < Struct.new( :data, :data_schema_version, :additional_data, :source) SENSITIVE = [:data] include Aws::Structure end |
#data_schema_version ⇒ String
The schema version of the descriptor payload.
1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1234 class McpServerDescriptor < Struct.new( :data, :data_schema_version, :additional_data, :source) SENSITIVE = [:data] include Aws::Structure end |
#source ⇒ Types::DescriptorSource
The optional source configuration used to synchronize the MCP server descriptor content.
1234 1235 1236 1237 1238 1239 1240 1241 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1234 class McpServerDescriptor < Struct.new( :data, :data_schema_version, :additional_data, :source) SENSITIVE = [:data] include Aws::Structure end |