Class: Aws::AgentRegistryControl::Types::PrivateEndpoint

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

Note:

PrivateEndpoint is a union - when making an API calls you must set exactly one of the members.

Note:

PrivateEndpoint is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PrivateEndpoint corresponding to the set member.

A private network endpoint used to reach a resource over a private path. Exactly one member is set.

Defined Under Namespace

Classes: ManagedVpcResource, SelfManagedLatticeResource, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#managed_vpc_resourceTypes::ManagedVpcResource

A private endpoint backed by a service-managed VPC resource.



1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1019

class PrivateEndpoint < Struct.new(
  :self_managed_lattice_resource,
  :managed_vpc_resource,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SelfManagedLatticeResource < PrivateEndpoint; end
  class ManagedVpcResource < PrivateEndpoint; end
  class Unknown < PrivateEndpoint; end
end

#self_managed_lattice_resourceTypes::SelfManagedLatticeResource

A private endpoint backed by a self-managed VPC Lattice resource configuration.



1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1019

class PrivateEndpoint < Struct.new(
  :self_managed_lattice_resource,
  :managed_vpc_resource,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SelfManagedLatticeResource < PrivateEndpoint; end
  class ManagedVpcResource < PrivateEndpoint; end
  class Unknown < PrivateEndpoint; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1019
1020
1021
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1019

def unknown
  @unknown
end