Class: Aws::AgentRegistryControl::Types::PrivateEndpointOverride
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::PrivateEndpointOverride
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
A mapping of a domain to the private endpoint used to reach it.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain name to which this private endpoint override applies.
-
#private_endpoint ⇒ Types::PrivateEndpoint
The private endpoint used to reach the specified domain.
Instance Attribute Details
#domain ⇒ String
The domain name to which this private endpoint override applies.
1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1044 class PrivateEndpointOverride < Struct.new( :domain, :private_endpoint) SENSITIVE = [] include Aws::Structure end |
#private_endpoint ⇒ Types::PrivateEndpoint
The private endpoint used to reach the specified domain.
1044 1045 1046 1047 1048 1049 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1044 class PrivateEndpointOverride < Struct.new( :domain, :private_endpoint) SENSITIVE = [] include Aws::Structure end |