Class: Aws::AgentRegistryControl::Types::SourceDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::SourceDetails
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
SourceDetails is a union - when making an API calls you must set exactly one of the members.
SourceDetails is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SourceDetails corresponding to the set member.
The details about the upstream source from which a registry record was detected. Exactly one member is populated, corresponding to the source type.
Defined Under Namespace
Classes: AgentcoreGateway, AgentcoreRuntime, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agentcore_gateway ⇒ Types::AgentCoreGatewaySourceDetails
Source details for a record auto-detected from an AgentCore Gateway resource.
-
#agentcore_runtime ⇒ Types::AgentCoreRuntimeSourceDetails
Source details for a record auto-detected from an AgentCore Runtime resource.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#agentcore_gateway ⇒ Types::AgentCoreGatewaySourceDetails
Source details for a record auto-detected from an AgentCore Gateway resource.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1746 class SourceDetails < Struct.new( :agentcore_runtime, :agentcore_gateway, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AgentcoreRuntime < SourceDetails; end class AgentcoreGateway < SourceDetails; end class Unknown < SourceDetails; end end |
#agentcore_runtime ⇒ Types::AgentCoreRuntimeSourceDetails
Source details for a record auto-detected from an AgentCore Runtime resource.
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1746 class SourceDetails < Struct.new( :agentcore_runtime, :agentcore_gateway, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AgentcoreRuntime < SourceDetails; end class AgentcoreGateway < SourceDetails; end class Unknown < SourceDetails; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1746 1747 1748 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1746 def unknown @unknown end |