Class: Aws::AgentRegistryControl::Types::UpdateRegistryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-agentregistrycontrol/types.rb

Overview

Request structure for updating a registry

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#approval_configurationTypes::UpdatedApprovalConfiguration

The updated approval configuration. The change applies only to records that move to PENDING_APPROVAL after the update; records already in PENDING_APPROVAL are unaffected.



1711
1712
1713
1714
1715
1716
1717
1718
1719
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1711

class UpdateRegistryRequest < Struct.new(
  :registry_id,
  :name,
  :description,
  :discovery_configuration,
  :approval_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionTypes::UpdatedDescription

The updated description of the registry



1711
1712
1713
1714
1715
1716
1717
1718
1719
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1711

class UpdateRegistryRequest < Struct.new(
  :registry_id,
  :name,
  :description,
  :discovery_configuration,
  :approval_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#discovery_configurationTypes::UpdatedDiscoveryConfiguration

The updated discovery configuration. Changing the discovery authorization can break existing consumers that rely on the previous authorization type.



1711
1712
1713
1714
1715
1716
1717
1718
1719
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1711

class UpdateRegistryRequest < Struct.new(
  :registry_id,
  :name,
  :description,
  :discovery_configuration,
  :approval_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The updated name of the registry

Returns:

  • (String)


1711
1712
1713
1714
1715
1716
1717
1718
1719
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1711

class UpdateRegistryRequest < Struct.new(
  :registry_id,
  :name,
  :description,
  :discovery_configuration,
  :approval_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#registry_idString

The identifier of the registry to update (ARN or ID)

Returns:

  • (String)


1711
1712
1713
1714
1715
1716
1717
1718
1719
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1711

class UpdateRegistryRequest < Struct.new(
  :registry_id,
  :name,
  :description,
  :discovery_configuration,
  :approval_configuration)
  SENSITIVE = []
  include Aws::Structure
end