Class: Aws::AgentRegistryControl::Types::UpdateRegistryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::UpdateRegistryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
Request structure for updating a registry
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approval_configuration ⇒ Types::UpdatedApprovalConfiguration
The updated approval configuration.
-
#description ⇒ Types::UpdatedDescription
The updated description of the registry.
-
#discovery_configuration ⇒ Types::UpdatedDiscoveryConfiguration
The updated discovery configuration.
-
#name ⇒ String
The updated name of the registry.
-
#registry_id ⇒ String
The identifier of the registry to update (ARN or ID).
Instance Attribute Details
#approval_configuration ⇒ Types::UpdatedApprovalConfiguration
The updated approval configuration. The change applies only to records that move to PENDING_APPROVAL after the update; records already in PENDING_APPROVAL are unaffected.
1711 1712 1713 1714 1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1711 class UpdateRegistryRequest < Struct.new( :registry_id, :name, :description, :discovery_configuration, :approval_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ Types::UpdatedDescription
The updated description of the registry
1711 1712 1713 1714 1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1711 class UpdateRegistryRequest < Struct.new( :registry_id, :name, :description, :discovery_configuration, :approval_configuration) SENSITIVE = [] include Aws::Structure end |
#discovery_configuration ⇒ Types::UpdatedDiscoveryConfiguration
The updated discovery configuration. Changing the discovery authorization can break existing consumers that rely on the previous authorization type.
1711 1712 1713 1714 1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1711 class UpdateRegistryRequest < Struct.new( :registry_id, :name, :description, :discovery_configuration, :approval_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The updated name of the registry
1711 1712 1713 1714 1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1711 class UpdateRegistryRequest < Struct.new( :registry_id, :name, :description, :discovery_configuration, :approval_configuration) SENSITIVE = [] include Aws::Structure end |
#registry_id ⇒ String
The identifier of the registry to update (ARN or ID)
1711 1712 1713 1714 1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1711 class UpdateRegistryRequest < Struct.new( :registry_id, :name, :description, :discovery_configuration, :approval_configuration) SENSITIVE = [] include Aws::Structure end |