Class: Aws::AgentRegistryControl::Types::UpdatedApprovalConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::UpdatedApprovalConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
A wrapper for updating the approval configuration of a registry. Include this wrapper to replace the approval configuration with the specified value; omit it to leave the approval configuration unchanged.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#optional_value ⇒ Types::ApprovalConfiguration
The value to set for this field.
Instance Attribute Details
#optional_value ⇒ Types::ApprovalConfiguration
The value to set for this field. Omit the wrapper to leave the field unchanged.
1951 1952 1953 1954 1955 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 1951 class UpdatedApprovalConfiguration < Struct.new( :optional_value) SENSITIVE = [] include Aws::Structure end |