Class: Aws::AgentRegistryControl::Types::UpdatedDiscoveryConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::AgentRegistryControl::Types::UpdatedDiscoveryConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-agentregistrycontrol/types.rb
Overview
The discovery configuration fields to update on a registry. Omit this structure to leave the discovery configuration unchanged.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorizer_configuration ⇒ Types::UpdatedAuthorizerConfiguration
Authorization configuration for the registry, with PATCH semantics.
Instance Attribute Details
#authorizer_configuration ⇒ Types::UpdatedAuthorizerConfiguration
Authorization configuration for the registry, with PATCH semantics
2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-agentregistrycontrol/types.rb', line 2125 class UpdatedDiscoveryConfiguration < Struct.new( :authorizer_configuration) SENSITIVE = [] include Aws::Structure end |