Class: Aws::AgentRegistryControl::Waiters::RegistryRecordApproved
- Inherits:
-
Object
- Object
- Aws::AgentRegistryControl::Waiters::RegistryRecordApproved
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-agentregistrycontrol/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ RegistryRecordApproved
constructor
A new instance of RegistryRecordApproved.
-
#wait(params = {}) ⇒ Types::GetRegistryRecordResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ RegistryRecordApproved
Returns a new instance of RegistryRecordApproved.
141 142 |
# File 'lib/aws-sdk-agentregistrycontrol/waiters.rb', line 141
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
185 186 187 |
# File 'lib/aws-sdk-agentregistrycontrol/waiters.rb', line 185 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetRegistryRecordResponse
Returns a response object which responds to the following methods:
- #registry_arn => String
- #record_arn => String
- #record_id => String
- #name => String
- #display_name => String
- #description => String
- #record_type => String
- #descriptors => Types::Descriptors
- #record_version => String
- #status => String
- #created_at => Time
- #updated_at => Time
- #status_reason => String
180 |
# File 'lib/aws-sdk-agentregistrycontrol/waiters.rb', line 180
def wait: (
|